@@ -139,12 +139,15 @@
 
 #ifdef LINUX
 #define SYSV_UTMP			/* SYSV-style utmp routines */
+#define NO_UTMP_INIT			/* no pre-login utmp entry */
+#define USE_GETCWD			/* getcwd() instead of getwd() */
 #define NO_TTYENT			/* no <ttyent.h> stuff */
 #define NO_SECURE_TTY			/* no "secure tty" concept */
 #define HAS_PATHS_H			/* /usr/include/paths.h */
-#define CONSOLE		"tty1"		/* no /dev/console */
-#define NBBY		8		/* not in <sys/mumble.h> */
 #define STDIO_DECLARES_SYS_ERRLIST	/* stdio.h declares sys_errlist */
+#define _PATH_LOGIN "/bin/login"	/* not /usr/bin/login */
+#define NEW_LOGIN			/* ruserok() done in rlogind */
+#define DIR_IS_OPAQUE			/* DIR handles are cookies */
 #endif
 
 #ifdef DECOSF1
