@@ -424,7 +424,7 @@ main(argc, argv)
 	/* Fill in wherefrom if it hasn't been done yet */
 	if (wherefrom[0] == '\0') {
 		if (hostname)
-			sprintf(wherefrom, "from %s", hostname);
+			sprintf(wherefrom, "from %.100s", hostname);
 		else
 			sprintf(wherefrom, "on %s", tty);
 	}
@@ -854,7 +854,7 @@ getloginname(prompt)
 void timedout()
 {
 	fprintf(stderr, "Login timed out after %d seconds\n", timeout);
-	exit(0);
+	close(0);	/* force EOF */
 }
 
 void hungup()
