@@ -1,5 +1,3 @@
-#ifdef DES_RPC
-
  /*
   * Decrypt the user's secret secure RPC key and stores it into the
   * keyserver. Returns 0 if successful, -1 on failure.
@@ -34,5 +32,3 @@ char   *passwd;
     }
     return (0);
 }
-
-#endif /* DES_RPC */
