@@ -2068,10 +2068,12 @@ char *
 btoe(engout,c)
 char *c, *engout;
 {
-	char cp[9];	/* add in room for the parity 2 bits*/
+	char cp[10];	/* add in room for the parity 2 bits + extract() slop */
 	int p,i ;
 
 	engout[0] = '\0';
+	/* workaround for extract() reads beyond end of data */
+	memset(cp, 0, sizeof(cp));
 	memcpy(cp, c,8);
 	/* compute parity */
 	for(p = 0,i = 0; i < 64;i += 2)
