@@ -64,7 +64,7 @@ extern	char	*ptsname();
 #include <sys/fcntl.h>
 #endif
 
-#if !defined(FIONBIO) && !defined(DECOSF1)
+#if !defined(FIONBIO) && !(defined(DECOSF1) || defined(LINUX))
 #include <sys/filio.h>
 #endif
 
@@ -431,9 +431,11 @@ gotpty:
 	 */
 #ifdef SYSV_UTMP
 	/* SYSV login insists on an utmp(x) entry */
+#ifndef NO_UTMP_INIT
 	if (UTMP_INIT(line + sizeof("/dev/") - 1, ".telnet", "tn") < 0)
 		fatalperror(2, "makeutx failed");
 #endif
+#endif
 #ifdef SYSV_ENV
 	execl(_PATH_LOGIN, "login", "-h", host,
 					terminaltype, (char *) 0);
